@@ -2,7 +2,7 @@
  *
  *  libproxy - A library for proxy configuration
  *
- *  Copyright (C) 2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2010-2011  Intel Corporation. All rights reserved.
  *
  *  This library is free software; you can redistribute it and/or modify
  *  it under the terms and conditions of the GNU Lesser General Public
@@ -77,12 +77,12 @@ static char **extract_result(const char *str)
 	result[0] = NULL;
 	result[1] = NULL;
 
-	if (strcmp(str, "DIRECT") == 0) {
+	if (strcasecmp(str, "DIRECT") == 0) {
 		result[0] = strdup("direct://");
 		return result;
 	}
 
-	if (strncmp(str, "PROXY ", 6) == 0) {
+	if (strncasecmp(str, "PROXY ", 6) == 0) {
 		int len = strlen(str + 6) + 8;
 		result[0] = malloc(len);
 		if (result[0] != NULL)
@@ -90,6 +90,30 @@ static char **extract_result(const char *str)
 		return result;
 	}
 
+	if (strncasecmp(str, "SOCKS ", 6) == 0) {
+		int len = strlen(str + 6) + 9;
+		result[0] = malloc(len);
+		if (result[0] != NULL)
+			sprintf(result[0], "socks://%s", str + 6);
+		return result;
+	}
+
+	if (strncasecmp(str, "SOCKS4 ", 7) == 0) {
+		int len = strlen(str + 7) + 10;
+		result[0] = malloc(len);
+		if (result[0] != NULL)
+			sprintf(result[0], "socks4://%s", str + 7);
+		return result;
+	}
+
+	if (strncasecmp(str, "SOCKS5 ", 7) == 0) {
+		int len = strlen(str + 7) + 10;
+		result[0] = malloc(len);
+		if (result[0] != NULL)
+			sprintf(result[0], "socks5://%s", str + 7);
+		return result;
+	}
+
 	return result;
 }
 
@@ -133,7 +157,7 @@ char **px_proxy_factory_get_proxies(pxProxyFactory *factory, const char *url)
 	port = strrchr(host, ':');
 	if (port != NULL) {
 		char *end;
-		int tmp;
+		int tmp __attribute__ ((unused));
 
 		tmp = strtol(port + 1, &end, 10);
 		if (*end == '\0')
